summaryrefslogtreecommitdiffhomepage
path: root/Kernel/Sources/FileManager.cxx
diff options
context:
space:
mode:
authorAmlal EL Mahrouss <amlalelmahrouss@icloud.com>2024-07-02 22:00:35 +0200
committerAmlal EL Mahrouss <amlalelmahrouss@icloud.com>2024-07-02 22:00:49 +0200
commit375d0210dcb2070a12d916523f4a1dafff28360c (patch)
treed0c217f529b8069ea659778c2ee9ca20aeba33a4 /Kernel/Sources/FileManager.cxx
parentf1d3744829a661d1600c2f3bbdbdf679ee0bd0e1 (diff)
MHR-36: Change namespace name, got out of the codename stage.
Signed-off-by: Amlal EL Mahrouss <amlalelmahrouss@icloud.com>
Diffstat (limited to 'Kernel/Sources/FileManager.cxx')
-rw-r--r--Kernel/Sources/FileManager.cxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/Kernel/Sources/FileManager.cxx b/Kernel/Sources/FileManager.cxx
index 11830252..35913b85 100644
--- a/Kernel/Sources/FileManager.cxx
+++ b/Kernel/Sources/FileManager.cxx
@@ -8,9 +8,9 @@
#include <NewKit/Utils.hpp>
/// BUGS: 0
-//! @brief File manager for NewOS.
+//! @brief File manager for Kernel.
-namespace NewOS
+namespace Kernel
{
static FilesystemManagerInterface* kMounted = nullptr;
@@ -189,4 +189,4 @@ namespace NewOS
return fImpl;
}
#endif // __FSKIT_NEWFS__
-} // namespace NewOS
+} // namespace Kernel